# Russian work calendar

## Setup
`pip install work_calendar_ru`

## Import package
`import work_calendar_ru.core as wcr`

## Using package
* Work time now `wcr.is_work_time()`
* Holiday today `wcr.is_holiday()`
* Work day today `wcr.is_work_day()`
* Short work day today `wcr.is_short_work_day()`
* Work weekend day today `wcr.is_work_weekend()`
* Weekend day today `wcr.is_weekend()`

## License
MIT license